#!/bin/bash
#
# PrivX Web-proxy post install script.
#
# Run after installing the rpm package.
#

# Parse arguments
for arg in "$@"
do
  case $arg in
    --log-to-file)
    logfile=/var/log/privx-install.log
    exec 3>&1 1>>${logfile} 2>&1
    echo "-----"
    echo "PrivX Web-proxy install "`date`
    echo
    ;;

    --request-cert)
    request_cert="yes"
    ;;

    *)
    echo "unknown argument $arg"
    exit 1
    ;;
  esac
done

# Check if need to skip automatic postinstall
case $SKIP_POSTINSTALL in
true|TRUE|1)
  echo
  echo "Skipping automatic post installation steps"
  echo
  echo "Please make sure to run the /opt/privx/scripts/web-proxy-postinstall.sh manually."
  echo
  exit 0
  ;;
*)
  ;;
esac

# Check that configuration file exists
echo "Checking web-proxy configuration file:"
webproxyconfig="/opt/privx/etc/web-proxy-config.toml"
if [ ! -r "$webproxyconfig" ]
then
  echo "$webproxyconfig missing."
  echo
  echo "Download web-proxy configuration from PrivX UI,"
  echo "copy it to $webproxyconfig"
  echo "and re-run /opt/privx/scripts/web-proxy-postinstall.sh"
  echo
  exit 0
fi
echo "done"

if ! grep -q ecap "/etc/squid/squid.conf"
then
  echo "$webproxyconfig needs upgrade."
  echo
  echo "Download web-proxy configuration from PrivX UI,"
  echo "copy it to $webproxyconfig"
  echo "and re-run /opt/privx/scripts/web-proxy-postinstall.sh"
  echo
  exit 1
fi

# Remove all permissions from other to keep credentials safe
chown root:privx $webproxyconfig
chmod 0640 $webproxyconfig
echo "done"

# Stop web-proxy
echo "Checking web-proxy status:"
if systemctl is-active privx-web-proxy
then
  echo "Stopping web-proxy:"
  systemctl stop privx-web-proxy
  echo "done"
fi

# Stop squid
echo "Checking squid status:"
if systemctl is-active squid
then
  echo "Stopping squid:"
  systemctl stop squid
  echo "done"
fi

# Register web-proxy to server
echo "Registering web-proxy:"

if [ -n "$request_cert" ]
then
  # Remove existing cert and private key to request a new cert
  certfile=`sed -n 's;certificate_file\s*=\s*"\(.*\)";\1;p' $webproxyconfig`
  keyfile=`sed -n 's;private_key_file\s*=\s*"\(.*\)";\1;p' $webproxyconfig`
  if [ -e "$certfile" ]; then mv -f "$certfile" "$certfile.bak"; fi
  if [ -e "$keyfile" ]; then mv -f "$keyfile" "$keyfile.bak"; fi
fi

su privx -c "/opt/privx/bin/privx-web-proxy -register"
status=$?

if [ $status -ne 0 ]
then
  if [ -e "$certfile.bak" ]; then mv -f "$certfile.bak" "$certfile"; fi
  if [ -e "$keyfile.bak" ]; then mv -f "$keyfile.bak" "$keyfile"; fi

  echo "Registration failed."
  echo "Check the following:"
  echo "  - Configuration in $webproxyconfig is correct"
  echo "  - PrivX server is reachable"
  echo "  - Web-proxy is not already registered in PrivX UI"
  echo "Re-run /opt/privx/scripts/web-proxy-postinstall.sh after fixing the problem."
  echo
  exit $status
fi
rm -f "$certfile.bak" "$keyfile.bak"
echo "done"

# Enable PrivX Web-proxy
echo "Enabling privx-web-proxy:"
chkconfig privx-web-proxy on
systemctl enable privx-web-proxy
echo "done"

# Enable squid
echo "Enabling squid:"
chkconfig squid on
systemctl enable squid
echo "done"

# Start PrivX Web-proxy
echo "Starting privx-web-proxy:"
systemctl restart privx-web-proxy
echo "done"

# Start squid
echo "Starting squid:"
systemctl restart squid
echo "done"

exit 0
